@@ -13,8 +13,7 @@
 #include "utility.h"
 #include "constants.h"
 #include "GeometricPrimitiveD.h"
-#include <boost/serialization/access.hpp>
-#include <boost/serialization/split_member.hpp>
+#include <cereal/access.hpp>
 #include <Eigen/Dense>
 
 #include <IMP/log.h>
@@ -55,21 +54,19 @@ class IMPALGEBRAEXPORT Rotation3D : public GeometricPrimitiveD<3> {
   mutable bool has_cache_;
   mutable Vector3D matrix_[3];
 
-  friend class boost::serialization::access;
+  friend class cereal::access;
 
   template<class Archive>
-  void save(Archive &ar, const unsigned int) const {
-    ar << v_;
+  void save(Archive &ar) const {
+    ar(v_);
   }
 
   template<class Archive>
-  void load(Archive &ar, const unsigned int) {
-    ar >> v_;
+  void load(Archive &ar) {
+    ar(v_);
     has_cache_ = false;
   }
 
-  BOOST_SERIALIZATION_SPLIT_MEMBER()
-
   IMP_NO_SWIG(friend Rotation3D compose(const Rotation3D &a,
                                         const Rotation3D &b));
   void fill_cache() const {
@@ -595,10 +592,10 @@ IMPALGEBRAEXPORT Rotation3D
 class FixedXYZ : public GeometricPrimitiveD<3> {
   double v_[3];
 
-  friend class boost::serialization::access;
+  friend class cereal::access;
 
-  template<class Archive> void serialize(Archive &ar, const unsigned int) {
-    ar & v_[0] & v_[1] & v_[2];
+  template<class Archive> void serialize(Archive &ar) {
+    ar(v_[0], v_[1], v_[2]);
   }
 
  public:
