@@ -2,7 +2,6 @@ from __future__ import print_function
 import IMP
 import IMP.test
 import IMP.algebra
-import math
 
 
 class Tests(IMP.test.TestCase):
@@ -21,8 +20,8 @@ class Tests(IMP.test.TestCase):
         print("the sample 1")
         for p in points:
             sampled_centroid = sampled_centroid + p
-            print(".sphere " + str(p[0]) + " " + str(p[1]) + " " + str(p[2])\
-                + " .1")
+            print(".sphere " + str(p[0]) + " " + str(p[1]) + " " + str(p[2])
+                  + " .1")
         sampled_centroid.show()
         sampled_centroid = sampled_centroid * (1.0 / len(points))
         sampled_centroid.show()
@@ -30,7 +29,7 @@ class Tests(IMP.test.TestCase):
                                delta=4 * radius / numpts ** .5)
 
     def test_get_uniform_surface_cover_not_on_000(self):
-        """Check uniform cover when the the center is not on (0,0,0)"""
+        """Check uniform cover when the center is not on (0,0,0)"""
         # IMP.random_number_generator.seed(1)
         center = IMP.algebra.Vector3D(4.0, 5.0, -9.0)
         radius = 5.0
@@ -45,8 +44,8 @@ class Tests(IMP.test.TestCase):
         print("the sample")
         for i in range(len(points)):
             sampled_centroid = sampled_centroid + points[i]
-            print(".dotat " + str(points[i][0]) + " "\
-                + str(points[i][1]) + "  " + str(points[i][2]))
+            print(".dotat " + str(points[i][0]) + " "
+                  + str(points[i][1]) + "  " + str(points[i][2]))
         sampled_centroid = sampled_centroid * (1.0 / len(points))
         sampled_centroid.show()
         center.show()
