@@ -9,7 +9,7 @@ class Tests(IMP.test.TestCase):
 
     def test_bonded(self):
         """Check use of Selection """
-        m = IMP.kernel.Model()
+        m = IMP.Model()
         mh = IMP.atom.read_pdb(self.get_input_file_name("input.pdb"),
                                m)
         pat = IMP.atom.Selection(mh, residue_index=10)
