@@ -1,6 +1,10 @@
 """Classes for handling the analysis of a modeling run.
 """
 
+
+from ihm.util import _text_choice_property
+
+
 class Step(object):
     """A single step in an :class:`Analysis`.
 
@@ -37,6 +41,10 @@ class Step(object):
         self.script_file = script_file
         self.details = details
 
+    feature = _text_choice_property(
+        "feature", ["energy/score", "RMSD", "dRMSD", "other", "none"],
+        doc="The feature used in the analysis, if applicable")
+
 
 class FilterStep(Step):
     """A single filtering step in an :class:`Analysis`.
@@ -72,9 +80,10 @@ class EmptyStep(Step):
        any kind of analysis.
     """
     type = 'none'
+
     def __init__(self):
         super(EmptyStep, self).__init__(
-                feature='none', num_models_begin=None, num_models_end=None)
+            feature='none', num_models_begin=None, num_models_end=None)
 
 
 class Analysis(object):
