@@ -8,16 +8,18 @@ import ihm.dataset
 import ihm.location
 import ihm.geometry
 
+
 def _make_test_file(fname):
     with open(fname, 'w') as fh:
         fh.write('contents')
 
+
 class Tests(unittest.TestCase):
 
     def test_dataset(self):
         """Test Dataset base class"""
-        l = ihm.location.PDBLocation('1abc', version='foo', details='bar')
-        d = ihm.dataset.Dataset(l)
+        loc = ihm.location.PDBLocation('1abc', version='foo', details='bar')
+        d = ihm.dataset.Dataset(loc)
         self.assertIsNone(d.details)
         self.assertEqual(len(d.parents), 0)
 
@@ -31,9 +33,9 @@ class Tests(unittest.TestCase):
         l3 = ihm.location.PDBLocation('1cde', version='foo', details='bar')
         d3 = ihm.dataset.Dataset(l3, details='bar')
         t = ihm.geometry.Transformation(
-            rot_matrix=[[-0.64,0.09,0.77],[0.76,-0.12,0.64],
-                        [0.15,0.99,0.01]],
-            tr_vector=[1.,2.,3.])
+            rot_matrix=[[-0.64, 0.09, 0.77], [0.76, -0.12, 0.64],
+                        [0.15, 0.99, 0.01]],
+            tr_vector=[1., 2., 3.])
         td = ihm.dataset.TransformedDataset(d3, transform=t)
         d.parents.append(td)
         self.assertEqual(len(d.parents), 2)
@@ -77,7 +79,7 @@ class Tests(unittest.TestCase):
         l3 = ihm.location.PDBLocation('2def', version='foo', details='bar')
         d3 = ihm.dataset.Dataset(l3)
 
-        l4 = ihm.location.PDBLocation('2ghi', version='foo', details='bar')
+        _ = ihm.location.PDBLocation('2ghi', version='foo', details='bar')
         d4 = ihm.dataset.Dataset(l3)
 
         d1.parents.extend((d2, d3))
@@ -90,6 +92,12 @@ class Tests(unittest.TestCase):
         d = ihm.dataset.CXMSDataset(loc)
         self.assertEqual(d.data_type, 'CX-MS data')
 
+    def test_hdx_dataset(self):
+        """Test HDXDataset"""
+        loc = ihm.location.FileLocation(repo='mydoi', path='a')
+        d = ihm.dataset.HDXDataset(loc)
+        self.assertEqual(d.data_type, 'H/D exchange data')
+
     def test_mass_spec_dataset(self):
         """Test MassSpecDataset"""
         loc = ihm.location.FileLocation(repo='mydoi', path='a')
@@ -162,6 +170,12 @@ class Tests(unittest.TestCase):
         d = ihm.dataset.FRETDataset(loc)
         self.assertEqual(d.data_type, 'Single molecule FRET data')
 
+    def test_ensemble_fret_dataset(self):
+        """Test EnsembleFRETDataset"""
+        loc = ihm.location.FileLocation(repo='mydoi', path='a')
+        d = ihm.dataset.EnsembleFRETDataset(loc)
+        self.assertEqual(d.data_type, 'Ensemble FRET data')
+
     def test_y2h_dataset(self):
         """Test YeastTwoHybridDataset"""
         loc = ihm.location.FileLocation(repo='mydoi', path='a')
@@ -172,8 +186,8 @@ class Tests(unittest.TestCase):
         """Test GeneticInteractionsDataset"""
         loc = ihm.location.FileLocation(repo='mydoi', path='a')
         d = ihm.dataset.GeneticInteractionsDataset(loc)
-        self.assertEqual(d.data_type,
-            'Quantitative measurements of genetic interactions')
+        self.assertEqual(
+            d.data_type, 'Quantitative measurements of genetic interactions')
 
     def test_duplicate_datasets_details(self):
         """Datasets with differing details should be considered duplicates"""
@@ -181,7 +195,7 @@ class Tests(unittest.TestCase):
             fname = os.path.join(tmpdir, 'test.pdb')
             _make_test_file(fname)
             l1 = ihm.location.InputFileLocation(fname, details='test details')
-            d1 = ihm.dataset.PDBDataset(l1)
+            _ = ihm.dataset.PDBDataset(l1)
 
             l2 = ihm.location.InputFileLocation(fname, details='other details')
             d2 = ihm.dataset.PDBDataset(l2)
