@@ -1,7 +1,7 @@
 /**
  *  \file IMP/core/ChecksScoreState.h    \brief Turn checks on and off.
  *
- *  Copyright 2007-2019 IMP Inventors. All rights reserved.
+ *  Copyright 2007-2022 IMP Inventors. All rights reserved.
  */
 
 #ifndef IMPCORE_CHECKS_SCORE_STATE_H
@@ -11,6 +11,8 @@
 #include <IMP/macros.h>
 #include <IMP/Particle.h>
 #include <IMP/ScoreState.h>
+#include <cereal/access.hpp>
+#include <cereal/types/base_class.hpp>
 
 IMPCORE_BEGIN_NAMESPACE
 
@@ -20,15 +22,22 @@ class IMPCOREEXPORT ChecksScoreState : public ScoreState {
   double probability_;
   unsigned int num_checked_;
 
+  friend class cereal::access;
+  template<class Archive> void serialize(Archive &ar) {
+    ar(cereal::base_class<ScoreState>(this), probability_, num_checked_);
+  }
+  IMP_OBJECT_SERIALIZE_DECL(ChecksScoreState);
+
  public:
   ChecksScoreState(Model *m, double probability);
+  ChecksScoreState() {}
 
   unsigned int get_number_of_checked() const { return num_checked_; }
 
-  virtual void do_before_evaluate() IMP_OVERRIDE;
-  virtual void do_after_evaluate(DerivativeAccumulator *da) IMP_OVERRIDE;
-  virtual ModelObjectsTemp do_get_outputs() const IMP_OVERRIDE;
-  virtual ModelObjectsTemp do_get_inputs() const IMP_OVERRIDE;
+  virtual void do_before_evaluate() override;
+  virtual void do_after_evaluate(DerivativeAccumulator *da) override;
+  virtual ModelObjectsTemp do_get_outputs() const override;
+  virtual ModelObjectsTemp do_get_inputs() const override;
   IMP_OBJECT_METHODS(ChecksScoreState);
 };
 
