@@ -25,12 +25,12 @@ class Tests(IMP.test.TestCase):
 
     def _test_basic(self, nm):
         """Testing default subset states"""
-        m = IMP.kernel.Model()
+        m = IMP.Model()
         ps = []
         ns = 5
         np = 4
         for i in range(0, np):
-            ps.append(IMP.kernel.Particle(m))
+            ps.append(IMP.Particle(m))
         pst = IMP.domino.ParticleStatesTable()
         pft = IMP.domino.ExclusionSubsetFilterTable(pst)
         dsst = nm(pst, [pft])
@@ -50,12 +50,12 @@ class Tests(IMP.test.TestCase):
 
     def _test_equivalencies(self, nm):
         """Testing default subset states with equivalencies"""
-        m = IMP.kernel.Model()
+        m = IMP.Model()
         ps = []
         ns = 5
         np = 4
         for i in range(0, np):
-            ps.append(IMP.kernel.Particle(m))
+            ps.append(IMP.Particle(m))
         pst = IMP.domino.ParticleStatesTable()
         tps = TrivialParticleStates(ns)
         pst.set_particle_states(ps[0], tps)
@@ -65,7 +65,7 @@ class Tests(IMP.test.TestCase):
         pft = IMP.domino.ExclusionSubsetFilterTable(pst)
         dsst = nm(pst, [pft])
         lsc = IMP.domino.Subset(ps)
-        IMP.base.set_log_level(IMP.base.SILENT)
+        IMP.set_log_level(IMP.SILENT)
         pss = IMP.domino.PackedAssignmentContainer()
         dsst.load_assignments(lsc, pss)
         ss = pss.get_assignments((0, pss.get_number_of_assignments()))
@@ -80,12 +80,12 @@ class Tests(IMP.test.TestCase):
 
     def _test_explicit(self, nm):
         """Testing default subset states with explicit equivalencies"""
-        m = IMP.kernel.Model()
+        m = IMP.Model()
         ps = []
         ns = 5
         np = 4
         for i in range(0, np):
-            ps.append(IMP.kernel.Particle(m))
+            ps.append(IMP.Particle(m))
         pst = IMP.domino.ParticleStatesTable()
         tps = TrivialParticleStates(ns)
         pst.set_particle_states(ps[0], tps)
@@ -96,7 +96,7 @@ class Tests(IMP.test.TestCase):
         pft.add_pair((ps[0], ps[1]))
         dsst = nm(pst, [pft])
         lsc = IMP.domino.Subset(ps)
-        IMP.base.set_log_level(IMP.base.SILENT)
+        IMP.set_log_level(IMP.SILENT)
         pss = IMP.domino.PackedAssignmentContainer()
         dsst.load_assignments(lsc, pss)
         ss = pss.get_assignments((0, pss.get_number_of_assignments()))
