@@ -211,6 +211,22 @@ class IMPEMEXPORT DensityHeader {
   //! How many bits are used to store the density of a single voxel
   //! (used in MRC format)
   int data_type_;
+
+private:
+  friend class cereal::access;
+
+  template<class Archive> void serialize(Archive &ar) {
+    ar(nxstart, nystart, nzstart, mx, my, mz, xlen, ylen, zlen,
+       alpha, beta, gamma, mapc, mapr, maps, dmin, dmax, dmean,
+       ispg, nsymbt, user, map, machinestamp, rms, nlabl, comments,
+       magic, voltage, Cs, Aperture, Magnification, Postmagnification,
+       Exposuretime, Microscope, Pixelsize, CCDArea, Defocus,
+       Astigmatism, AstigmatismAngle, FocusIncrement, CountsPerElectron,
+       Intensity, EnergySlitwidth, EnergyOffset, Tiltangle, Tiltaxis,
+       MarkerX, MarkerY, lswap, Objectpixelsize_, xtop_, ytop_, ztop_,
+       xorigin_, yorigin_, zorigin_, top_calculated_, resolution_,
+       is_resolution_set_, nx_, ny_, nz_, data_type_);
+  }
 };
 
 //! Create a header from a bounding box in 3D
