@@ -1,7 +1,7 @@
 /**
  *  \file IMP/em2d/ProjectionMask.h
  *  \brief projection masks
- *  Copyright 2007-2022 IMP Inventors. All rights reserved.
+ *  Copyright 2007-2023 IMP Inventors. All rights reserved.
 */
 
 #ifndef IMPEM2D_PROJECTION_MASK_H
@@ -9,7 +9,6 @@
 
 #include <IMP/em2d/em2d_config.h>
 #include "IMP/em2d/opencv_interface.h"
-#include "IMP/em2d/CenteredMat.h"
 #include "IMP/atom/Mass.h"
 #include "IMP/em/exp.h"
 #include "IMP/algebra/Vector3D.h"
@@ -21,17 +20,16 @@
 #include "IMP/Particle.h"
 #include "IMP/exception.h"
 #include <complex>
-#include <boost/shared_ptr.hpp>
-#include <boost/serialization/access.hpp>
-#include <boost/serialization/split_free.hpp>
+#include <memory>
+#include <cereal/access.hpp>
 
 IMPEM2D_BEGIN_NAMESPACE
 
 class ProjectionMask;
 class MasksManager;
 
-typedef boost::shared_ptr<ProjectionMask> ProjectionMaskPtr;
-typedef boost::shared_ptr<MasksManager> MasksManagerPtr;
+typedef std::shared_ptr<ProjectionMask> ProjectionMaskPtr;
+typedef std::shared_ptr<MasksManager> MasksManagerPtr;
 
 //! Mask that contains the projection of a given particles. This matrices
 //! speed up projecting because the only have to be computed once for a model
@@ -67,10 +65,10 @@ class IMPEM2DEXPORT ProjectionMask {
   double sq_pixelsize_;  // Used to save multiplications
   cv::Mat data_;         // actual matrix with the mask
 private:
-  friend class boost::serialization::access;
+  friend class cereal::access;
 
-  template<class Archive> void serialize(Archive &ar, const unsigned int) {
-    ar & dim_ & sq_pixelsize_ & data_;
+  template<class Archive> void serialize(Archive &ar) {
+    ar(dim_, sq_pixelsize_, data_);
   }
 };
 
@@ -78,38 +76,29 @@ IMP_VALUES(ProjectionMask, ProjectionMasks);
 
 IMPEM2D_END_NAMESPACE
 
-namespace boost {
-  namespace serialization {
-    template<class Archive> inline void save(
-         Archive &ar, const std::map<double, IMP::em2d::ProjectionMaskPtr> &m,
-         const unsigned int) {
-      size_t sz = m.size();
-      ar << sz;
-      for (const auto &p : m) {
-        ar << p.first;
-        ar << *(p.second);
-      }
+namespace cereal {
+  template<class Archive> inline void save(
+       Archive &ar, const std::map<double,
+                               IMP::em2d::ProjectionMaskPtr> &m) {
+    size_t sz = m.size();
+    ar(sz);
+    for (const auto &p : m) {
+      ar(p.first);
+      ar(*(p.second));
     }
+  }
 
-    template<class Archive> inline void load(
-         Archive &ar, std::map<double, IMP::em2d::ProjectionMaskPtr> &m,
-         const unsigned int) {
-      m.clear();
-      size_t sz;
-      ar >> sz;
-      for (size_t i = 0; i < sz; ++i) {
-        double mass;
-        IMP::em2d::ProjectionMaskPtr ptr(new IMP::em2d::ProjectionMask());
-        ar >> mass;
-        ar >> *ptr;
-        m[mass] = ptr;
-      }
-    }
-
-    template<class Archive> inline void serialize(
-         Archive &ar, std::map<double, IMP::em2d::ProjectionMaskPtr> &m,
-         const unsigned int version) {
-      boost::serialization::split_free(ar, m, version);
+  template<class Archive> inline void load(
+       Archive &ar, std::map<double, IMP::em2d::ProjectionMaskPtr> &m) {
+    m.clear();
+    size_t sz;
+    ar(sz);
+    for (size_t i = 0; i < sz; ++i) {
+      double mass;
+      IMP::em2d::ProjectionMaskPtr ptr(new IMP::em2d::ProjectionMask());
+      ar(mass);
+      ar(*ptr);
+      m[mass] = ptr;
     }
   }
 }
@@ -221,10 +210,10 @@ class IMPEM2DEXPORT MasksManager {
   bool is_setup_;
 
 private:
-  friend class boost::serialization::access;
+  friend class cereal::access;
 
-  template<class Archive> void serialize(Archive &ar, const unsigned int) {
-    ar & mass2mask_ & kernel_params_ & pixelsize_ & is_setup_;
+  template<class Archive> void serialize(Archive &ar) {
+    ar(mass2mask_, kernel_params_, pixelsize_, is_setup_);
   }
 
 };
