@@ -4,8 +4,6 @@ import IMP.atom as atom
 import IMP.core as core
 import IMP.em2d as em2d
 import IMP.test
-import os
-import random
 import csv
 import itertools
 import logging
@@ -13,7 +11,7 @@ log = logging.getLogger("tests")
 
 
 def is_comment(list_values, comment_char="#"):
-    if(len(list_values) == 0 or list_values[0][0] == comment_char):
+    if len(list_values) == 0 or list_values[0][0] == comment_char:
         return True
     return False
 
@@ -34,7 +32,7 @@ def parse_relative_transform(row):
 def get_relative_transforms(fn_transforms):
     f = open(fn_transforms, "r")
     reader = csv.reader(f, delimiter=" ")
-    rows = [d for d in reader if(not is_comment(d))]
+    rows = [d for d in reader if not is_comment(d)]
     f.close()
     return [parse_relative_transform(row) for row in rows]
 
@@ -58,10 +56,8 @@ def get_docked_reference_frames(relative_transforms, rb_lig):
 
 
 def apply_random_transform(rb, max_trans=100):
-    """
-        Apply a random transformation to the rigid body and change the reference
-        frame
-    """
+    """Apply a random transformation to the rigid body and change the
+       reference frame"""
     bb = alg.BoundingBox3D(alg.Vector3D(-max_trans, -max_trans, -max_trans),
                            alg.Vector3D(max_trans, max_trans, max_trans))
     Trand = alg.Transformation3D(alg.get_random_rotation_3d(),
@@ -84,20 +80,20 @@ class Tests(IMP.test.TestCase):
         fn_rec1 = self.get_input_file_name("1suvA_xlinked.pdb")
         fn_rec2 = self.get_input_file_name("1suvC_xlinked.pdb")
         fn_lig = self.get_input_file_name("1suvE_xlinked.pdb")
-        fn_tr1  = \
+        fn_tr1 = \
             self.get_input_file_name("transforms-1suvA-1suvE_reduced.txt")
-        fn_tr2  = \
+        fn_tr2 = \
             self.get_input_file_name("transforms-1suvC-1suvE_filtered.txt")
         m = IMP.Model()
         sel = atom.ATOMPDBSelector()
         h_rec1 = atom.read_pdb(fn_rec1, m, sel)
         rb_rec1 = atom.create_rigid_body(h_rec1)
-        rec1_coords = [core.XYZ(l).get_coordinates()
-                       for l in atom.get_leaves(h_rec1)]
+        _ = [core.XYZ(leaf).get_coordinates()
+             for leaf in atom.get_leaves(h_rec1)]
         h_rec2 = atom.read_pdb(fn_rec2, m, sel)
         rb_rec2 = atom.create_rigid_body(h_rec2)
-        rec2_coords = [core.XYZ(l).get_coordinates()
-                       for l in atom.get_leaves(h_rec2)]
+        _ = [core.XYZ(leaf).get_coordinates()
+             for leaf in atom.get_leaves(h_rec2)]
         h_ligand = atom.read_pdb(fn_lig, m, sel)
         rb_lig = atom.create_rigid_body(h_ligand)
 
@@ -120,25 +116,24 @@ class Tests(IMP.test.TestCase):
         mv.add_internal_transformations(rb_rec2, Tis2)
 
         for i in range(2):
-#            prob_random = 0
-            ref_before = rb_lig.get_reference_frame()
-            ps = mv.propose()  # _move(prob_random)
-            ref_after = rb_lig.get_reference_frame()
+            _ = rb_lig.get_reference_frame()
+            _ = mv.propose()
+            _ = rb_lig.get_reference_frame()
             found = False
-            current_coords = [core.XYZ(l).get_coordinates()
-                              for l in atom.get_leaves(h_ligand)]
+            current_coords = [core.XYZ(leaf).get_coordinates()
+                              for leaf in atom.get_leaves(h_ligand)]
             # check all possible reference frames where the ligand could be
             for r in itertools.chain(docked_refs1, docked_refs2):
                 rb_lig.set_reference_frame(r)
-                docked_coords = [core.XYZ(l).get_coordinates()
-                                 for l in atom.get_leaves(h_ligand)]
+                docked_coords = [core.XYZ(leaf).get_coordinates()
+                                 for leaf in atom.get_leaves(h_ligand)]
                 rmsd = alg.get_rmsd(current_coords, docked_coords)
                 if rmsd < 0.1:
                     found = True
             self.assertTrue(found, msg="the proposed move is not "
                             "in the relative solutions")
             mv.accept()
-#            os.remove(fn_proposed)
+
 
 if __name__ == '__main__':
     IMP.test.main()
