@@ -36,11 +36,13 @@ int main(int argc, char **argv) {
   unsigned int n_components = 1;
   std::vector<std::string> image_files;
   std::string pdb;
-  po::options_description desc(
+  std::string desc_prefix(
       "Usage: <pdb> <image1> <image2>...\n\n"
       "This program is part of IMP, the Integrative Modeling Platform,\n"
-      "which is Copyright 2007-2022 IMP Inventors.\n\n"
-      "Options");
+      "which is ");
+  po::options_description desc(
+      desc_prefix + IMP::get_copyright() + ".\n\nOptions");
+
   desc.add_options()
     ("help", "Show command line arguments and exit.")
     ("version", "Show version info and exit.")(
