@@ -50,12 +50,14 @@ int main(int argc, char **argv) {
   int units = 1; // determine automatically
   bool vr_score = false;
 
-  po::options_description desc(
+  std::string desc_prefix(
       "Usage: <pdb1> <pdb2> <trans file> <exp profile file>\n"
       "\nProgram for scoring of docking models with SAXS profile.\n\n"
       "This program is part of IMP, the Integrative Modeling Platform,\n"
-      "which is Copyright 2007-2022 IMP Inventors.\n\n"
-      "Options");
+      "which is ");
+  po::options_description desc(
+      desc_prefix + IMP::get_copyright() + ".\n\nOptions");
+
   desc.add_options()
     ("help", "Show command line arguments and exit.")
     ("version", "Show version info and exit.")(
