@@ -2,14 +2,14 @@
  *  \file IMP/isd/GaussianEMRestraint.h
  *  \brief Restrain two sets of Gaussians (model and GMM derived from EM map)
  *
- *  Copyright 2007-2019 IMP Inventors. All rights reserved.
+ *  Copyright 2007-2022 IMP Inventors. All rights reserved.
  *
  */
 
 #ifndef IMPISD_GAUSSIAN_EM_RESTRAINT_H
 #define IMPISD_GAUSSIAN_EM_RESTRAINT_H
 
-#include "isd_config.h"
+#include <IMP/isd/isd_config.h>
 #include <IMP/file.h>
 #include <IMP/PairContainer.h>
 #include <IMP/container/ListSingletonContainer.h>
@@ -23,6 +23,8 @@
 #include <math.h>
 #include <Eigen/Dense>
 #include <boost/unordered_map.hpp>
+#include <cereal/access.hpp>
+#include <cereal/types/vector.hpp>
 
 IMPISD_BEGIN_NAMESPACE
 
@@ -48,6 +50,7 @@ class IMPISDEXPORT GaussianEMRestraint : public Restraint
      \param[in] model_ps particles for the model GMM
      \param[in] density_ps particles for the density GMM
      \param[in] global_sigma Particle to modulate the uncertainty
+                (currently unused)
      \param[in] model_cutoff_dist Cutoff for the model-model interactions
      \param[in] density_cutoff_dist Cutoff for model-density interactions
      \param[in] slope Gentle term to move all particles to the density
@@ -66,6 +69,7 @@ class IMPISDEXPORT GaussianEMRestraint : public Restraint
                       bool update_model=true, bool backbone_slope=false,
                       bool local=false,
                       std::string name="GaussianEMRestraint%1%");
+  GaussianEMRestraint() {}
 
   //! Returns exp(score)
   double get_probability() const {
@@ -102,15 +106,15 @@ class IMPISDEXPORT GaussianEMRestraint : public Restraint
   //! Get restraint slope
   Float get_slope(){return slope_;}
   virtual double
-    unprotected_evaluate(IMP::DerivativeAccumulator *accum) const IMP_OVERRIDE;
-  virtual IMP::ModelObjectsTemp do_get_inputs() const IMP_OVERRIDE;
+    unprotected_evaluate(IMP::DerivativeAccumulator *accum) const override;
+  virtual IMP::ModelObjectsTemp do_get_inputs() const override;
   void show(std::ostream &out) const { out << "GEM restraint"; }
 
   //! \return Information for writing to RMF files
-  RestraintInfo *get_static_info() const IMP_OVERRIDE;
+  RestraintInfo *get_static_info() const override;
 
   //! \return Information for writing to RMF files
-  RestraintInfo *get_dynamic_info() const IMP_OVERRIDE;
+  RestraintInfo *get_dynamic_info() const override;
 
   IMP_OBJECT_METHODS(GaussianEMRestraint);
 
@@ -118,7 +122,6 @@ class IMPISDEXPORT GaussianEMRestraint : public Restraint
   double model_cutoff_dist_, density_cutoff_dist_;
   ParticleIndexes model_ps_;
   ParticleIndexes density_ps_;
-  ParticleIndex global_sigma_;
   Float slope_;
   bool update_model_,local_;
   int msize_,dsize_;
@@ -136,6 +139,25 @@ class IMPISDEXPORT GaussianEMRestraint : public Restraint
   double argmax_;
 
   mutable double cross_correlation_;
+
+  //! Create containers of model and density particles
+  void create_containers();
+
+  friend class cereal::access;
+
+  template<class Archive> void serialize(Archive &ar) {
+    ar(cereal::base_class<Restraint>(this), model_cutoff_dist_,
+       density_cutoff_dist_, model_ps_, density_ps_, slope_, update_model_,
+       local_, msize_,dsize_, normalization_, dd_score_, self_mm_score_,
+       slope_ps_, density_fn_, exp_grid_,
+       invdx_, argmax_, cross_correlation_);
+    // recreate md_container and mm_container on input
+    if (std::is_base_of<cereal::detail::InputArchiveBase, Archive>::value) {
+      create_containers();
+    }
+  }
+
+  IMP_OBJECT_SERIALIZE_DECL(GaussianEMRestraint);
 };
 
 IMPISD_END_NAMESPACE
