@@ -25,19 +25,19 @@ IMPISD_BEGIN_NAMESPACE
 // First constructor, with particles for multiple donors and acceptors
 // Bayesian parameters are: kda, Ida, R0, uncertainty,
 // and photobleaching survival rate
-FretRestraint::FretRestraint(Particles pd, Particles pa,
+FretRestraint::FretRestraint(ParticlesTemp pd, ParticlesTemp pa,
                              Particle *kda, Particle *Ida,
                              Particle *R0, Particle *sigma0,
                              Particle *Pbl, double fexp, double m_d,
                              double m_a)
     : Restraint(kda->get_model(), "FretRestraint%1%"),
-      pd_(pd),
-      pa_(pa),
-      kda_(kda),
-      Ida_(Ida),
-      R0_(R0),
-      sigma0_(sigma0),
-      Pbl_(Pbl),
+      pd_(IMP::get_indexes(pd)),
+      pa_(IMP::get_indexes(pa)),
+      kda_(kda->get_index()),
+      Ida_(Ida->get_index()),
+      R0_(R0->get_index()),
+      sigma0_(sigma0->get_index()),
+      Pbl_(Pbl->get_index()),
       fexp_(fexp),
       multi_d_(m_d),
       constr_type_(0) {
@@ -61,11 +61,11 @@ FretRestraint::FretRestraint(Particle *kda, Particle *Ida,
                              Particle *sumFi, Particle *sigma0,
                              Particle *Pbl, double fexp)
     : Restraint(kda->get_model(), "FretRestraint%1%"),
-      kda_(kda),
-      Ida_(Ida),
-      sumFi_(sumFi),
-      sigma0_(sigma0),
-      Pbl_(Pbl),
+      kda_(kda->get_index()),
+      Ida_(Ida->get_index()),
+      sumFi_(sumFi->get_index()),
+      sigma0_(sigma0->get_index()),
+      Pbl_(Pbl->get_index()),
       fexp_(fexp),
       constr_type_(1) {};
 
@@ -81,16 +81,16 @@ FretRestraint::FretRestraint(Particle *prd, algebra::Vector3D GMMterd,
                              Particle *Ida, Particle *sigma0,
                              Particle *Pbl, FretData *data, double fexp)
     : Restraint(kda->get_model(), "FretRestraint%1%"),
-      prd_(prd),
+      prd_(prd->get_index()),
       GMMterd_(GMMterd),
       GMMctrd_(GMMctrd),
-      pra_(pra),
+      pra_(pra->get_index()),
       GMMtera_(GMMtera),
       GMMctra_(GMMctra),
-      kda_(kda),
-      Ida_(Ida),
-      sigma0_(sigma0),
-      Pbl_(Pbl),
+      kda_(kda->get_index()),
+      Ida_(Ida->get_index()),
+      sigma0_(sigma0->get_index()),
+      Pbl_(Pbl->get_index()),
       data_(data),
       fexp_(fexp),
       constr_type_(2) {
@@ -110,7 +110,7 @@ void FretRestraint::set_experimental_value(double fexp) { fexp_ = fexp; }
 
 // get average sigma
 double FretRestraint::get_average_sigma(double fmod) const {
-  double sigma0 = Scale(sigma0_).get_scale();
+  double sigma0 = Scale(get_model(), sigma0_).get_scale();
 
   double B = 0.5 * log(fexp_ / fmod) * log(fexp_ / fmod) + sigma0 * sigma0;
 
@@ -195,13 +195,14 @@ double FretRestraint::get_sumFi(double Pbleach) const {
 
 // type 0
 double FretRestraint::get_model_fretr_type_0() const {
+  Model *m = get_model();
   // thresold for forster factor
   const double thres = 0.01;
   // get scales
-  double Ida = Scale(Ida_).get_scale();
-  double kda = Scale(kda_).get_scale();
-  double R0 = Scale(R0_).get_scale();
-  double Pbl = Scale(Pbl_).get_scale();
+  double Ida = Scale(m, Ida_).get_scale();
+  double kda = Scale(m, kda_).get_scale();
+  double R0 = Scale(m, R0_).get_scale();
+  double Pbl = Scale(m, Pbl_).get_scale();
 
   double sumFi = 0.;
   double sumFi_bl = 0.;
@@ -209,9 +210,9 @@ double FretRestraint::get_model_fretr_type_0() const {
   for (unsigned i = 0; i < pd_.size(); ++i) {
     power6_.clear();
     for (unsigned j = 0; j < pa_.size(); ++j) {
-      double dist =
-          std::max(core::get_distance(core::XYZ(pd_[i]), core::XYZ(pa_[j])),
-                   std::numeric_limits<double>::epsilon());
+      double dist = std::max(
+              core::get_distance(core::XYZ(m, pd_[i]), core::XYZ(m, pa_[j])),
+              std::numeric_limits<double>::epsilon());
       double R = R0 / dist;
       double R6 = R * R * R * R * R * R;
       if (R6 > thres) {
@@ -245,7 +246,7 @@ double FretRestraint::get_model_fretr_type_0() const {
 }
 
 algebra::Vector3Ds FretRestraint::get_current_centers(
-    Particle *p, const algebra::Vector3Ds &ctrs) const {
+    ParticleIndex p, const algebra::Vector3Ds &ctrs) const {
 
   algebra::Vector3Ds new_ctrs;
   for (unsigned i = 0; i < ctrs.size(); ++i) {
@@ -255,9 +256,10 @@ algebra::Vector3Ds FretRestraint::get_current_centers(
 }
 
 algebra::Vector3D FretRestraint::get_current_center(
-    Particle *p, const algebra::Vector3D &ctr) const {
+    ParticleIndex p, const algebra::Vector3D &ctr) const {
 
-  algebra::ReferenceFrame3D rf = core::RigidBody(p).get_reference_frame();
+  algebra::ReferenceFrame3D
+       rf = core::RigidBody(get_model(), p).get_reference_frame();
   return rf.get_global_coordinates(ctr);
 }
 
@@ -287,15 +289,16 @@ double FretRestraint::get_sumFi() const {
 }
 
 double FretRestraint::get_model_fretr_type_1() const {
+  Model *m = get_model();
   double sumFi;
   if (constr_type_ == 1) {
-    sumFi = Scale(sumFi_).get_scale();
+    sumFi = Scale(m, sumFi_).get_scale();
   } else {
     sumFi = get_sumFi();
   }
-  double Ida = Scale(Ida_).get_scale();
-  double kda = Scale(kda_).get_scale();
-  double Pbl = Scale(Pbl_).get_scale();
+  double Ida = Scale(m, Ida_).get_scale();
+  double kda = Scale(m, kda_).get_scale();
+  double Pbl = Scale(m, Pbl_).get_scale();
 
   double fretr = (Ida * sumFi + 1. + kda * (1. - sumFi)) /
                  (Ida * (Pbl * sumFi + (1. - Pbl)) + 1.);
@@ -311,7 +314,7 @@ double FretRestraint::get_probability() const {
 
   double log_eps = log(fexp_ / fretr);
 
-  double sigma0 = Scale(sigma0_).get_scale();
+  double sigma0 = Scale(get_model(), sigma0_).get_scale();
 
   double prob = sqrt(2.) * sigma0 / fexp_ / IMP::PI /
                 (log_eps * log_eps + 2. * sigma0 * sigma0);
@@ -341,24 +344,27 @@ double FretRestraint::unprotected_evaluate(DerivativeAccumulator *accum) const {
 /* Return all particles whose attributes are read by the restraints. To
    do this, ask the pair score what particles it uses.*/
 ModelObjectsTemp FretRestraint::do_get_inputs() const {
+  Model *m = get_model();
   ParticlesTemp ret;
-  ret.push_back(Ida_);
-  ret.push_back(kda_);
-  ret.push_back(sigma0_);
-  ret.push_back(Pbl_);
+  ret.push_back(m->get_particle(Ida_));
+  ret.push_back(m->get_particle(kda_));
+  ret.push_back(m->get_particle(sigma0_));
+  ret.push_back(m->get_particle(Pbl_));
   if (constr_type_ == 0) {
-    ret.insert(ret.end(), pd_.begin(), pd_.end());
-    ret.insert(ret.end(), pa_.begin(), pa_.end());
-    ret.push_back(R0_);
+    ret += IMP::get_particles(m, pd_);
+    ret += IMP::get_particles(m, pa_);
+    ret.push_back(m->get_particle(R0_));
   }
   if (constr_type_ == 1) {
-    ret.push_back(sumFi_);
+    ret.push_back(m->get_particle(sumFi_));
   }
   if (constr_type_ == 2) {
-    ret.push_back(prd_);
-    ret.push_back(pra_);
+    ret.push_back(m->get_particle(prd_));
+    ret.push_back(m->get_particle(pra_));
   }
   return ret;
 }
 
+IMP_OBJECT_SERIALIZE_IMPL(IMP::isd::FretRestraint);
+
 IMPISD_END_NAMESPACE
