@@ -2,7 +2,7 @@
  *  \file IMP/ScoringFunction.h
  *  \brief Represents a scoring function on the model.
  *
- *  Copyright 2007-2018 IMP Inventors. All rights reserved.
+ *  Copyright 2007-2022 IMP Inventors. All rights reserved.
  *
  */
 
@@ -14,9 +14,11 @@
 #include "dependency_graph.h"
 #include "Restraint.h"
 #include "ModelObject.h"
+#include "internal/moved_particles_cache.h"
 #include <IMP/InputAdaptor.h>
 #include <IMP/Pointer.h>
-
+#include <cereal/access.hpp>
+#include <cereal/types/base_class.hpp>
 #include <limits>
 
 IMPKERNEL_BEGIN_NAMESPACE
@@ -39,6 +41,27 @@ being evaluated (this is cached)
 */
 class IMPKERNELEXPORT ScoringFunction : public ModelObject {
   EvaluationState es_;
+  // cache of ScoreStates that are affected by each moved particle,
+  // used for evaluate_moved() and related functions
+  internal::MovedParticlesScoreStateCache moved_particles_cache_;
+  // time when moved_particles_cache_ was last updated, or 0
+  unsigned moved_particles_cache_age_;
+
+  friend class cereal::access;
+
+  template<class Archive> void serialize(Archive &ar) {
+    ar(cereal::base_class<ModelObject>(this), es_);
+    // clear caches
+    if (std::is_base_of<cereal::detail::InputArchiveBase, Archive>::value) {
+      moved_particles_cache_.clear();
+      moved_particles_cache_age_ = 0;
+    }
+  }
+
+  ScoreStatesTemp get_moved_required_score_states(
+                               const ParticleIndexes &moved_pis,
+                               const ParticleIndexes &reset_pis);
+
   // later make things implement inputs and return restraints
  public:
   typedef std::pair<double, bool> ScoreIsGoodPair;
@@ -49,6 +72,19 @@ class IMPKERNELEXPORT ScoringFunction : public ModelObject {
       is passed.*/
   virtual void do_add_score_and_derivatives(ScoreAccumulator sa,
                                             const ScoreStatesTemp &ss) = 0;
+
+  //! Score when only some particles have moved.
+  /** \see do_add_score_and_derivatives()
+   */
+  virtual void do_add_score_and_derivatives_moved(
+                  ScoreAccumulator sa, const ParticleIndexes &moved_pis,
+                  const ParticleIndexes &reset_pis,
+                  const ScoreStatesTemp &ss) {
+    IMP_UNUSED(moved_pis);
+    IMP_UNUSED(reset_pis);
+    do_add_score_and_derivatives(sa, ss);
+  }
+
   ScoreAccumulator get_score_accumulator_if_below(bool deriv, double max) {
     return ScoreAccumulator(&es_, 1.0, deriv, max, NO_MAX, true);
   }
@@ -61,14 +97,13 @@ class IMPKERNELEXPORT ScoringFunction : public ModelObject {
 
  public:
   ScoringFunction(Model *m, std::string name);
+  ScoringFunction();
 
-  virtual ModelObjectsTemp do_get_outputs() const IMP_OVERRIDE {
+  virtual ModelObjectsTemp do_get_outputs() const override {
     return ModelObjectsTemp();
   }
 
-  double evaluate_if_good(bool derivatives);
-
-  //! Evaluate and return the score
+  //! Evaluate and return the score for the current state of the model.
   /** \return the resulting score
 
       @param derivatives if true, updates the derivatives of the
@@ -76,8 +111,40 @@ class IMPKERNELEXPORT ScoringFunction : public ModelObject {
   */
   double evaluate(bool derivatives);
 
+  double evaluate_if_good(bool derivatives);
+
   double evaluate_if_below(bool derivatives, double max);
 
+  //! Score when some particles have moved.
+  /** No particles in the model other those listed should have been
+      changed (e.g. by Monte Carlo movers) since the last evaluation (although
+      ScoreStates may have moved particles not in this list, as a function of
+      particles that *are* in the list). This should behave identically to
+      evaluate() but may be more efficient if it can skip restraint terms
+      that involve unchanged particles.
+
+      \see IMP::core::MonteCarlo::set_score_moved
+
+      \param calc_derivs Whether to calculate first derivatives.
+      \param moved_pis Particles that have moved since the last
+             scoring function evaluation.
+      \param reset_pis Particles that have moved, but back to the
+             positions they had at the last-but-one evaluation
+             (e.g. due to a rejected Monte Carlo move).
+
+      \see evaluate()
+   */
+  double evaluate_moved(bool derivatives, const ParticleIndexes &moved_pis,
+                        const ParticleIndexes &reset_pis);
+
+  double evaluate_moved_if_below(
+             bool derivatives, const ParticleIndexes &moved_pis,
+             const ParticleIndexes &reset_pis, double max);
+
+  double evaluate_moved_if_good(
+             bool derivatives, const ParticleIndexes &moved_pis,
+             const ParticleIndexes &reset_pis);
+
   /** Return true if the last evaluate satisfied all the restraint
       thresholds.*/
   bool get_had_good_score() const { return es_.good; }
