@@ -1,8 +1,8 @@
 /**
  *  \file IMP/decorator_macros.h
- *  \brief Various general useful macros for IMP.
+ *  \brief Helper macros for implementing Decorators
  *
- *  Copyright 2007-2020 IMP Inventors. All rights reserved.
+ *  Copyright 2007-2022 IMP Inventors. All rights reserved.
  *
  */
 
@@ -17,8 +17,6 @@
 #include <IMP/showable_macros.h>
 #include <IMP/warning_macros.h>
 
-
-
 /** Implement the needed methods for a decorator based on
     - setup_particle()
     - get_is_setup()
@@ -109,22 +107,28 @@
     defined.
 */
 #define IMP_DECORATOR_SETUP_0(Name)                                    \
-  /** Setup the particle so it can be used with this decorator. */     \
-  static Name setup_particle(Model *m, ParticleIndex pi) {     \
+  /**								       
+     @return a Name object that decorates particle pi                  
+  */							               \
+  static Name setup_particle(Model *m, ParticleIndex pi) {             \
     IMP_USAGE_CHECK(!get_is_setup(m, pi),                              \
                     "Particle " << m->get_particle_name(pi)            \
                                 << " already set up as " << #Name);    \
     do_setup_particle(m, pi);                                          \
     return Name(m, pi);                                                \
   }                                                                    \
-  static Name setup_particle(IMP::ParticleAdaptor decorator) { \
-    return setup_particle(decorator.get_model(),                       \
-                          decorator.get_particle_index());             \
+  /** @return a Name object that decorates the particle specified by pa                  
+     \see setup_particle(m, p) */			       \
+  static Name setup_particle(IMP::ParticleAdaptor pa) {		       \
+    return setup_particle(pa.get_model(),                       \
+                          pa.get_particle_index());             \
   }
 /** \see IMP_DECORATOR_SETUP_0() */
 #define IMP_DECORATOR_SETUP_1(Name, FirstArgumentType, first_argument_name) \
-  /** Setup the particle so that it can be used with this decorator */  \
-  static Name setup_particle(Model *m, ParticleIndex pi,        \
+  /**								        
+     @return a Name object that decorates particle pi                   
+  */							                \
+  static Name setup_particle(Model *m, ParticleIndex pi,                \
                              FirstArgumentType first_argument_name) {   \
     IMP_USAGE_CHECK(!get_is_setup(m, pi),                               \
                     "Particle " << m->get_particle_name(pi)             \
@@ -132,19 +136,22 @@
     do_setup_particle(m, pi, first_argument_name);                      \
     return Name(m, pi);                                                 \
   }                                                                     \
-  /** \see setup_particle(m, pi, first_argument_name) */                \
-  static Name setup_particle(IMP::ParticleAdaptor decorator,    \
+  /** @return a Name object that decorates the particle specified by pa                  
+      \see setup_particle(m, pi, first_argument_name) */ \
+  static Name setup_particle(IMP::ParticleAdaptor pa,    \
                              FirstArgumentType first_argument_name) {   \
-    return setup_particle(decorator.get_model(),                        \
-                          decorator.get_particle_index(),               \
+    return setup_particle(pa.get_model(),                        \
+                          pa.get_particle_index(),               \
                           first_argument_name);                         \
   }
 
 /** \see IMP_DECORATOR_SETUP_0() */
 #define IMP_DECORATOR_SETUP_2(Name, FirstArgumentType, first_argument_name,    \
                               SecondArgumentType, second_argument_name)        \
-  /** Setup the particle so it can be used with this decorator. */             \
-  static Name setup_particle(Model *m, ParticleIndex pi,               \
+  /**								       
+     @return a Name object that decorates particle pi                  
+  */							                       \
+  static Name setup_particle(Model *m, ParticleIndex pi,		       \
                              FirstArgumentType first_argument_name,            \
                              SecondArgumentType second_argument_name) {        \
     IMP_USAGE_CHECK(!get_is_setup(m, pi),                                      \
@@ -153,19 +160,24 @@
     do_setup_particle(m, pi, first_argument_name, second_argument_name);       \
     return Name(m, pi);                                                        \
   }                                                                            \
-  static Name setup_particle(IMP::ParticleAdaptor decorator,           \
+  /** @return a Name object that decorates the particle specified by pa                  
+     \see setup_particle(m, p, first_argument_name, second_argument_name)
+  */									\
+  static Name setup_particle(IMP::ParticleAdaptor pa,                   \
                              FirstArgumentType first_argument_name,            \
                              SecondArgumentType second_argument_name) {        \
-    return setup_particle(decorator.get_model(),                               \
-                          decorator.get_particle_index(), first_argument_name, \
+    return setup_particle(pa.get_model(),                               \
+                          pa.get_particle_index(), first_argument_name, \
                           second_argument_name);                               \
   }
 /** \see IMP_DECORATOR_SETUP_0() */
 #define IMP_DECORATOR_SETUP_3(Name, FirstArgumentType, first_argument_name,    \
                               SecondArgumentType, second_argument_name,        \
                               ThirdArgumentType, third_argument_name)          \
-  /** Setup the particle so it can be used with this decorator. */             \
-  static Name setup_particle(Model *m, ParticleIndex pi,               \
+  /**								       
+     @return a Name object that decorates particle pi                  
+  */							                       \
+  static Name setup_particle(Model *m, ParticleIndex pi,                       \
                              FirstArgumentType first_argument_name,            \
                              SecondArgumentType second_argument_name,          \
                              ThirdArgumentType third_argument_name) {          \
@@ -175,13 +187,16 @@
     do_setup_particle(m, pi, first_argument_name, second_argument_name,        \
                       third_argument_name);                                    \
     return Name(m, pi);                                                        \
-  }                                                                            \
-  static Name setup_particle(IMP::ParticleAdaptor decorator,           \
+  }									       \
+  /** @return a Name object that decorates the particle specified by pa                  
+      \see setup_particle(m, pi, first_argument_name, second_argument_name,    
+      third_argument_name) */ 						       \
+  static Name setup_particle(IMP::ParticleAdaptor pa,                          \
                              FirstArgumentType first_argument_name,            \
                              SecondArgumentType second_argument_name,          \
                              ThirdArgumentType third_argument_name) {          \
-    return setup_particle(decorator.get_model(),                               \
-                          decorator.get_particle_index(), first_argument_name, \
+    return setup_particle(pa.get_model(),                                      \
+                          pa.get_particle_index(), first_argument_name,        \
                           second_argument_name, third_argument_name);          \
   }
 /** \see IMP_DECORATOR_SETUP_0() */
@@ -189,8 +204,10 @@
                               SecondArgumentType, second_argument_name,        \
                               ThirdArgumentType, third_argument_name,          \
                               FourthArgumentType, fourth_argument_name)        \
-  /** Setup the particle so it can be used with this decorator. */             \
-  static Name setup_particle(Model *m, ParticleIndex pi,               \
+  /**								               
+     @return a Name object that decorates particle pi                          
+  */							                       \
+  static Name setup_particle(Model *m, ParticleIndex pi,                       \
                              FirstArgumentType first_argument_name,            \
                              SecondArgumentType second_argument_name,          \
                              ThirdArgumentType third_argument_name,            \
@@ -201,14 +218,17 @@
     do_setup_particle(m, pi, first_argument_name, second_argument_name,        \
                       third_argument_name, fourth_argument_name);              \
     return Name(m, pi);                                                        \
-  }                                                                            \
-  static Name setup_particle(IMP::ParticleAdaptor decorator,           \
+  }									       \
+  /** @return a Name object that decorates the particle specified by pa
+      \see setup_particle(m, pi, first_argument_name, second_argument_name,
+      third_argument_name, fourth_argument_name) */ 			       \
+  static Name setup_particle(IMP::ParticleAdaptor pa,                          \
                              FirstArgumentType first_argument_name,            \
                              SecondArgumentType second_argument_name,          \
                              ThirdArgumentType third_argument_name,            \
                              FourthArgumentType fourth_argument_name) {        \
-    return setup_particle(decorator.get_model(),                               \
-                          decorator.get_particle_index(), first_argument_name, \
+    return setup_particle(pa.get_model(),                                      \
+                          pa.get_particle_index(), first_argument_name,        \
                           second_argument_name, third_argument_name,           \
                           fourth_argument_name);                               \
   }
@@ -220,13 +240,15 @@
                               ThirdArgumentType, third_argument_name,          \
                               FourthArgumentType, fourth_argument_name,        \
                               FifthArgumentType, fifth_argument_name)          \
-  /** Setup the particle so it can be used with this decorator. */             \
+  /**								               
+     @return a Name object that decorates particle pi                          
+  */							                       \
   static Name setup_particle(Model *m, ParticleIndex pi,                       \
                              FirstArgumentType first_argument_name,            \
                              SecondArgumentType second_argument_name,          \
                              ThirdArgumentType third_argument_name,            \
                              FourthArgumentType fourth_argument_name,          \
-                             FifthArgumentType fifth_argument_name) {         \
+                             FifthArgumentType fifth_argument_name) {          \
     IMP_USAGE_CHECK(!get_is_setup(m, pi),                                      \
                     "Particle " << m->get_particle_name(pi)                    \
                                 << " already set up as " << #Name);            \
@@ -235,14 +257,17 @@
                       fifth_argument_name);                                    \
     return Name(m, pi);                                                        \
   }                                                                            \
-  static Name setup_particle(IMP::ParticleAdaptor decorator,                   \
+    /** @return a Name object that decorates the particle specified by pa                  
+	\see setup_particle(m, pi, first_argument_name, second_argument_name,    
+	third_argument_name, fourth_argument_name, fifth_argument_name) */ \
+  static Name setup_particle(IMP::ParticleAdaptor pa,                   \
                              FirstArgumentType first_argument_name,            \
                              SecondArgumentType second_argument_name,          \
                              ThirdArgumentType third_argument_name,            \
                              FourthArgumentType fourth_argument_name,          \
-                             FifthArgumentType fifth_argument_name) {         \
-    return setup_particle(decorator.get_model(),                               \
-                          decorator.get_particle_index(), first_argument_name, \
+                             FifthArgumentType fifth_argument_name) {          \
+    return setup_particle(pa.get_model(),                               \
+                          pa.get_particle_index(), first_argument_name, \
                           second_argument_name, third_argument_name,           \
                           fourth_argument_name, fifth_argument_name);          \
   }
@@ -254,7 +279,9 @@
     defined. But any docs needed before the macro invocation.
 */
 #define IMP_DECORATOR_TRAITS_SETUP_0(Name)                         \
-  /** Setup the particle so it can be used with this decorator. */ \
+  /**								       
+     @return a Name object that decorates particle pi                  
+  */							               \
   static Name setup_particle(                                      \
       Model *m, ParticleIndex pi,                          \
       DecoratorTraits tr = get_default_decorator_traits()) {       \
@@ -457,7 +484,7 @@
    and publicly getting that constraint. The constraint is added as a
    score state to the model.
  */
-#define IMP_CONSTRAINT_DECORATOR_DEF(Name)                                \
+#define IMP_CONSTRAINT_DECORATOR_DEF(Name, can_skip)                      \
   ObjectKey Name::get_constraint_key() {                                  \
     static ObjectKey ret(#Name " score state");                           \
     return ret;                                                           \
@@ -474,7 +501,8 @@
     } else {                                                            \
       Constraint* ss = new core::SingletonConstraint(                     \
           before, after, m, pi,                                           \
-          std::string(#Name "updater for ") + m->get_particle_name(pi));  \
+          std::string(#Name "updater for ") + m->get_particle_name(pi),   \
+          can_skip);                                                      \
       m->add_attribute(get_constraint_key(), pi, ss);                     \
       m->add_score_state(ss);                                             \
     }                                                                     \
@@ -557,7 +585,7 @@
 */
 #define IMP_SUMMARIZE_DECORATOR_DEF(Name, Parent, Members,                \
                                   create_pre_modifier,                  \
-                                  create_post_modifier)                 \
+                                  create_post_modifier, can_skip)       \
   void Name::do_setup_particle(Model *m, ParticleIndex pi,      \
                                const ParticleIndexes &pis) {            \
     Refiner *ref = new FixedRefiner(IMP::get_particles(m, pis)); \
@@ -578,6 +606,6 @@
     void Name::show(std::ostream &out) const {                          \
       out << #Name << " at " << static_cast<Parent>(*this);             \
     }                                                                   \
-      IMP_CONSTRAINT_DECORATOR_DEF(Name)
+      IMP_CONSTRAINT_DECORATOR_DEF(Name, can_skip)
 
 #endif /* IMPKERNEL_DECORATOR_MACROS_H */
