@@ -2,7 +2,7 @@
  *  \file core/generic.h    \brief Various important functionality
  *                                       for implementing decorators.
  *
- *  Copyright 2007-2021 IMP Inventors. All rights reserved.
+ *  Copyright 2007-2022 IMP Inventors. All rights reserved.
  *
  */
 
@@ -15,6 +15,8 @@
 #include "create_decomposition.h"
 #include "AccumulatorScoreModifier.h"
 #include "functors.h"
+#include <cereal/access.hpp>
+#include <cereal/types/base_class.hpp>
 
 IMPKERNEL_BEGIN_INTERNAL_NAMESPACE
 /** When programming in C++, you can use ContainerRestraint instead
@@ -24,21 +26,35 @@ IMPKERNEL_BEGIN_INTERNAL_NAMESPACE
 template <class Score, class Container>
 class ContainerRestraint : public Restraint {
   IMP::PointerMember<Container> pc_;
+  IMP::Pointer<Score> ss_;
   IMP::Pointer<AccumulatorScoreModifier<Score, Container> > acc_;
 
+  friend class cereal::access;
+
+  template<class Archive> void serialize(Archive &ar) {
+    ar(cereal::base_class<Restraint>(this), pc_, ss_);
+
+    // recreate the AccumulatorScoreModifier
+    if (std::is_base_of<cereal::detail::InputArchiveBase, Archive>::value) {
+      acc_ = create_accumulator_score_modifier(ss_.get(), pc_.get());
+    }
+  }
+
  public:
   ContainerRestraint(Score *ss, Container *pc,
                      std::string name = "GroupnamesRestraint %1%");
 
+  ContainerRestraint() {}
+
  public:
   void do_add_score_and_derivatives(IMP::ScoreAccumulator sa) const
-      IMP_OVERRIDE;
+      override;
 
   void do_add_score_and_derivatives_moved(IMP::ScoreAccumulator sa,
                 const ParticleIndexes &moved_pis,
-                const ParticleIndexes &reset_pis) const IMP_OVERRIDE;
+                const ParticleIndexes &reset_pis) const override;
 
-  ModelObjectsTemp do_get_inputs() const IMP_OVERRIDE;
+  ModelObjectsTemp do_get_inputs() const override;
   IMP_OBJECT_METHODS(ContainerRestraint);
   ;
 
@@ -49,10 +65,10 @@ class ContainerRestraint : public Restraint {
 
   Score *get_score() const { return acc_->get_score_object(); }
 
-  Restraints do_create_decomposition() const IMP_OVERRIDE;
-  Restraints do_create_current_decomposition() const IMP_OVERRIDE;
+  Restraints do_create_decomposition() const override;
+  Restraints do_create_current_decomposition() const override;
 
-  IMP_IMPLEMENT(double get_last_score() const IMP_OVERRIDE;);
+  IMP_IMPLEMENT(double get_last_score() const override;);
 };
 
 /** Helper to create a ContainerRestraint without specifying the types. Make
@@ -74,6 +90,7 @@ ContainerRestraint<Score, C>::ContainerRestraint(Score *ss, C *pc,
                                                  std::string name)
     : Restraint(pc->get_model(), name),
       pc_(pc),
+      ss_(ss),
       acc_(create_accumulator_score_modifier(ss, pc)) {}
 
 template <class Score, class C>
