@@ -2,7 +2,7 @@
  *  \file generic.h    \brief Various important functionality
  *                                       for implementing decorators.
  *
- *  Copyright 2007-2019 IMP Inventors. All rights reserved.
+ *  Copyright 2007-2022 IMP Inventors. All rights reserved.
  *
  */
 
@@ -14,6 +14,8 @@
 #include "container_helpers.h"
 #include <IMP/Pointer.h>
 #include "../constants.h"
+#include <cereal/access.hpp>
+#include <cereal/types/base_class.hpp>
 
 IMPKERNEL_BEGIN_INTERNAL_NAMESPACE
 
@@ -22,6 +24,12 @@ class TupleRestraint : public Restraint {
   IMP::PointerMember<Score> ss_;
   typename Score::IndexArgument v_;
 
+  friend class cereal::access;
+
+  template<class Archive> void serialize(Archive &ar) {
+    ar(cereal::base_class<Restraint>(this), ss_, v_);
+  }
+
  public:
   //! Create the restraint.
   /** This function takes the function to apply to the
@@ -29,6 +37,7 @@ class TupleRestraint : public Restraint {
   */
   TupleRestraint(Score *ss, Model *m, const typename Score::IndexArgument &vt,
                  std::string name = "TupleRestraint %1%");
+  TupleRestraint() {}
 
   Score *get_score() const { return ss_; }
   typename Score::Argument get_argument() const {
@@ -36,11 +45,11 @@ class TupleRestraint : public Restraint {
   }
 
  public:
-  double unprotected_evaluate(DerivativeAccumulator *accum) const IMP_OVERRIDE;
-  ModelObjectsTemp do_get_inputs() const IMP_OVERRIDE;
+  double unprotected_evaluate(DerivativeAccumulator *accum) const override;
+  ModelObjectsTemp do_get_inputs() const override;
   IMP_OBJECT_METHODS(TupleRestraint);
   ;
-  Restraints do_create_current_decomposition() const;
+  Restraints do_create_current_decomposition() const override;
 };
 
 template <class Score>
