@@ -2,7 +2,7 @@
  *  \file internal/attribute_tables.h
  *  \brief Access to particle attributes.
  *
- *  Copyright 2007-2020 IMP Inventors. All rights reserved.
+ *  Copyright 2007-2022 IMP Inventors. All rights reserved.
  *
  */
 
@@ -11,10 +11,12 @@
 
 #include <IMP/kernel_config.h>
 #include <boost/dynamic_bitset.hpp>
+#include <cereal/access.hpp>
 #include "../Key.h"
 #include "../utility.h"
 #include "../FloatIndex.h"
 #include "input_output_exception.h"
+#include "KeyVector.h"
 #include <IMP/exception.h>
 #include <IMP/check_macros.h>
 #include <IMP/log.h>
@@ -70,12 +72,19 @@ class BasicAttributeTable {
   typedef typename Traits::Key Key;
 
  private:
-  Vector<typename Traits::Container> data_;
+  KeyVector<typename Traits::Key, typename Traits::Container> data_;
 #if IMP_HAS_CHECKS >= IMP_INTERNAL
   Mask *read_mask_, *write_mask_, *add_remove_mask_;
 #endif
   IMP_KERNEL_SMALL_UNORDERED_SET<Key> caches_;
 
+  friend class cereal::access;
+
+  template<class Archive> void serialize(Archive &ar) {
+    // Note that we don't serialize masks; they are handled by Model
+    ar(caches_, data_);
+  }
+
   void do_add_attribute(Key k, ParticleIndex particle,
                         typename Traits::PassValue value) {
     IMP_USAGE_CHECK(Traits::get_is_valid(value),
@@ -289,6 +298,15 @@ class FloatAttributeTable {
   Mask *read_mask_, *write_mask_, *add_remove_mask_, *read_derivatives_mask_,
       *write_derivatives_mask_;
 #endif
+
+  friend class cereal::access;
+
+  template<class Archive> void serialize(Archive &ar) {
+    // Note that we don't serialize masks; they are handled by Model
+    ar(spheres_, sphere_derivatives_, internal_coordinates_);
+    ar(internal_coordinate_derivatives_, data_, derivatives_, optimizeds_);
+  }
+
   algebra::Sphere3D get_invalid_sphere() const {
     double iv = internal::FloatAttributeTableTraits::get_invalid();
     algebra::Sphere3D ivs(algebra::Vector3D(iv, iv, iv), iv);
@@ -851,6 +869,8 @@ typedef BasicAttributeTable<internal::WeakObjectAttributeTableTraits>
     WeakObjectAttributeTable;
 typedef BasicAttributeTable<internal::IntsAttributeTableTraits>
     IntsAttributeTable;
+typedef BasicAttributeTable<internal::FloatsAttributeTableTraits>
+    FloatsAttributeTable;
 typedef BasicAttributeTable<internal::ObjectsAttributeTableTraits>
     ObjectsAttributeTable;
 typedef BasicAttributeTable<internal::ParticleAttributeTableTraits>
