@@ -2,7 +2,7 @@
  *  \file IMP/exception.h
  *  \brief Exception definitions and assertions.
  *
- *  Copyright 2007-2019 IMP Inventors. All rights reserved.
+ *  Copyright 2007-2022 IMP Inventors. All rights reserved.
  *
  */
 
@@ -24,7 +24,7 @@ struct IMPKERNELEXPORT InputOutputException : public std::runtime_error {
   InputOutputException(int particle_index, int operation, int entity,
                        std::string key_name);
   InputOutputException(std::string container_name, int entity);
-  ~InputOutputException() IMP_NOEXCEPT;
+  ~InputOutputException() noexcept;
   enum AccessEntity {
     NO_ENTITY,
     ATTRIBUTE,
