@@ -4,7 +4,7 @@
  *
  *  \authors Dina Schneidman, Barak Raveh
  *
- *  Copyright 2007-2021 IMP Inventors. All rights reserved.
+ *  Copyright 2007-2022 IMP Inventors. All rights reserved.
  *
  */
 
@@ -19,7 +19,7 @@
 #include <IMP/Sampler.h>
 #include <IMP/ConfigurationSet.h>
 
-#include <boost/shared_ptr.hpp>
+#include <memory>
 
 IMPKINEMATICS_BEGIN_NAMESPACE
 
@@ -119,7 +119,7 @@ class IMPKINEMATICSEXPORT RRT : public IMP::Sampler {
   // function required by Sampler
   // TODO: think how to save configurations in internal coords
   // to be more memory efficient
-  IMP::ConfigurationSet* do_sample() const IMP_OVERRIDE {
+  IMP::ConfigurationSet* do_sample() const override {
     const_cast<RRT*>(this)->run();
     return nullptr;
   }
@@ -173,7 +173,7 @@ class IMPKINEMATICSEXPORT RRT : public IMP::Sampler {
  private:
   PointerMember<DOFsSampler> dofs_sampler_;
   PointerMember<LocalPlanner> local_planner_;
-  typedef boost::shared_ptr<RRTNode> RRTNodePtr;
+  typedef std::shared_ptr<RRTNode> RRTNodePtr;
   typedef std::vector<RRTNodePtr> RRTTree;
   RRTTree tree_;
   DOFs cspace_dofs_;               // configuration space dofs
