@@ -10,6 +10,7 @@ import ihm.startmodel
 import ihm.analysis
 import ihm.protocol
 import ihm.model
+import ihm.citations
 
 
 def get_molecule(h):
@@ -426,20 +427,44 @@ class _Datasets(object):
 
 class _AllSoftware(object):
     """Keep track of all Software objects."""
+
+    # IMP/RMF doesn't store citation info for software, so provide it
+    # for known software packages
+    cites = {'Integrative Modeling Platform (IMP)': ihm.citations.imp,
+             'IMP PMI module': ihm.citations.pmi}
+
     def __init__(self, system):
         self.system = system
+        self._by_namever = {}
         super(_AllSoftware, self).__init__()
 
     def add_hierarchy(self, h):
         # todo: if no SoftwareProvenance available, use RMF producer field
         for p in IMP.core.get_all_provenance(
                 h, types=[IMP.core.SoftwareProvenance]):
-            self.system.software.append(
-                    ihm.Software(name=p.get_software_name(),
-                                 classification='integrative model building',
-                                 description=None,
-                                 version=p.get_version(),
-                                 location=p.get_location()))
+            self._add_provenance(p)
+
+    def _add_provenance(self, p):
+        """Add Software from SoftwareProvenance"""
+        # Only reference the same version of a given software package once
+        name = p.get_software_name()
+        version = p.get_version()
+        if (name, version) not in self._by_namever:
+            s = ihm.Software(name=name,
+                             classification='integrative model building',
+                             description=None, version=version,
+                             location=p.get_location(),
+                             citation=self.cites.get(name))
+            self.system.software.append(s)
+            self._by_namever[name, version] = s
+        return self._by_namever[name, version]
+
+    def _add_previous_provenance(self, prov):
+        """Add Software from a previous SoftwareProvenance, if any"""
+        while prov:
+            if IMP.core.SoftwareProvenance.get_is_setup(prov):
+                return self._add_provenance(IMP.core.SoftwareProvenance(prov))
+            prov = prov.get_previous()
 
 
 class _ExternalFiles(object):
@@ -467,7 +492,7 @@ class _ExternalFiles(object):
 
 class _ProtocolStep(ihm.protocol.Step):
     """A single step (e.g. sampling, refinement) in a protocol."""
-    def __init__(self, prov, num_models_begin, assembly):
+    def __init__(self, prov, num_models_begin, assembly, all_software):
         method = prov.get_method()
         if prov.get_number_of_replicas() > 1:
             method = "Replica exchange " + method
@@ -481,7 +506,8 @@ class _ProtocolStep(ihm.protocol.Step):
                 # todo: support multiple states, time ordered
                 multi_state=False, ordered=False,
                 # todo: revisit assumption all models are multiscale
-                multi_scale=True)
+                multi_scale=True,
+                software=all_software._add_previous_provenance(prov))
 
     def add_combine(self, prov):
         self.num_models_end = prov.get_number_of_frames()
@@ -494,14 +520,14 @@ class _Protocol(ihm.protocol.Protocol):
        refinement) followed by a number of postprocessing steps (e.g.
        filtering, rescoring, clustering)"""
 
-    def add_step(self, prov, num_models, assembly):
+    def add_step(self, prov, num_models, assembly, all_software):
         if isinstance(prov, IMP.core.CombineProvenance):
             # Fold CombineProvenance into a previous sampling step
             if len(self.steps) == 0:
                 raise ValueError("CombineProvenance with no previous sampling")
             return self.steps[-1].add_combine(prov)
         else:
-            ps = _ProtocolStep(prov, num_models, assembly)
+            ps = _ProtocolStep(prov, num_models, assembly, all_software)
             self.steps.append(ps)
             return ps.num_models_end
 
@@ -532,7 +558,7 @@ class _Protocols(object):
     def _add_protocol(self, prot):
         self.system.orphan_protocols.append(prot)
 
-    def _add_hierarchy(self, h, modeled_assembly):
+    def _add_hierarchy(self, h, modeled_assembly, all_software):
         num_models = 0  # assume we always start with no models
         prot_types = (IMP.core.SampleProvenance, IMP.core.CombineProvenance)
         pp_types = (IMP.core.FilterProvenance, IMP.core.ClusterProvenance)
@@ -548,7 +574,8 @@ class _Protocols(object):
                     # Start a new protocol
                     self._add_protocol(prot)
                     prot = _Protocol()
-                num_models = prot.add_step(p, num_models, modeled_assembly)
+                num_models = prot.add_step(p, num_models, modeled_assembly,
+                                           all_software)
                 in_postproc = False
         if len(prot.steps) > 0:
             self._add_protocol(prot)
