@@ -1,7 +1,7 @@
 /**
  *  \file GeometricComplementarity.cpp   \brief Geometric complementarity.
  *
- *  Copyright 2007-2021 IMP Inventors. All rights reserved.
+ *  Copyright 2007-2022 IMP Inventors. All rights reserved.
  *
  */
 
@@ -29,7 +29,7 @@ class SurfaceDistanceMap : public IMP::em::SampledDensityMap {
 
   // Resample needs to be overloaded so that the number of layers
   // is not limited by num_shells_
-  void resample() IMP_OVERRIDE;
+  void resample() override;
 
  private:
   void set_surface_shell(std::vector<long> *shell);
