@@ -42,7 +42,7 @@ using namespace IMP::container;
 
 namespace {
 const double radius = 2;
-#if IMP_BUILD < IMP_FAST
+#if IMP_BUILD == IMP_DEBUG
 int number_of_particles = 5;
   //int step_size = 8;
 #else
