@@ -2,7 +2,7 @@
  *  \file AnchorToCylidnricalPorePairScore.h
  *  \brief A chore for anchoring a bead to a pore
  *
- *  Copyright 2007-2020 IMP Inventors. All rights reserved.
+ *  Copyright 2007-2022 IMP Inventors. All rights reserved.
  */
 
 #ifndef IMPNPCTRANSPORT_ANCHOR_TO_CYLINDRICAL_PORE_PAIR_SCORE_H
@@ -77,11 +77,11 @@ AnchorToCylidnricalPorePairScore : public PairScore
   virtual double evaluate_index
     (Model *m,
      const ParticleIndexPair& pip,
-     DerivativeAccumulator *da) const IMP_OVERRIDE;
+     DerivativeAccumulator *da) const override;
 
   virtual ModelObjectsTemp do_get_inputs(Model *m,
                                          const ParticleIndexes &pis) const
-      IMP_OVERRIDE;
+      override;
 
   IMP_PAIR_SCORE_METHODS(AnchorToCylidnricalPorePairScore);
   IMP_OBJECT_METHODS(AnchorToCylidnricalPorePairScore);
