@@ -2,7 +2,7 @@
  *  \file RMF/HDF5/handle.h
  *  \brief Handle read/write of Model data from/to files.
  *
- *  Copyright 2007-2021 IMP Inventors. All rights reserved.
+ *  Copyright 2007-2022 IMP Inventors. All rights reserved.
  *
  */
 
@@ -49,7 +49,7 @@ class RMFEXPORT Handle : public boost::noncopyable {
           IOException);
     }
   }
-  Handle() : h_(-1), f_(NULL) {}
+  Handle() : h_(-1), f_(nullptr) {}
   hid_t get_hid() const {
     RMF_USAGE_CHECK(h_ >= 0, "Uninitialized handle used.");
     return h_;
@@ -70,7 +70,13 @@ class RMFEXPORT Handle : public boost::noncopyable {
     }
     h_ = -1;
   }
-  ~Handle() RMF_CANEXCEPT {
+// Older clang does not like exception specification in combination
+// with std::shared_ptr
+#if defined(__clang__) && __clang_major__ <= 7
+  ~Handle() {
+#else
+  ~Handle() noexcept(false) {
+#endif
     if (h_ != -1) {
       RMF_HDF5_CALL(f_(h_));
     }
