@@ -2,7 +2,7 @@
  *  \file RMF/compiler_macros.h
  *  \brief Various compiler workarounds
  *
- *  Copyright 2007-2018 IMP Inventors. All rights reserved.
+ *  Copyright 2007-2022 IMP Inventors. All rights reserved.
  */
 
 #ifndef RMF_INTERNAL_COMPILER_MACROS_H
@@ -21,56 +21,19 @@
 #endif
 #endif
 
-#ifdef __clang__
-#define RMF_COMPILER_HAS_OVERRIDE 1
-#elif defined(__GNUC__) && __cplusplus >= 201103L
-// probably should be finer here
-#define RMF_COMPILER_HAS_OVERRIDE 1
-#else
-#define RMF_COMPILER_HAS_OVERRIDE 0
-#endif
-
-#if RMF_COMPILER_HAS_OVERRIDE
+// Deprecated; just use 'override' keyword instead
 #define RMF_OVERRIDE override
-#else
-#define RMF_OVERRIDE
-#endif
 
-#ifdef __clang__
-#define RMF_COMPILER_HAS_FINAL 1
-#elif defined(__GNUC__) && __cplusplus >= 201103L
-// probably should be finer here
-#define RMF_COMPILER_HAS_FINAL 1
-#else
-#define RMF_COMPILER_HAS_FINAL 0
-#endif
-
-#if RMF_COMPILER_HAS_FINAL
+// Deprecated; just use 'final' keyword instead
 #define RMF_FINAL final
-#else
-#define RMF_FINAL
-#endif
 
-#if defined(__GNUC__) && __cplusplus >= 201103L
-#define RMF_HAS_NOEXCEPT 1
-#elif defined(__clang__) && defined(__has_feature)
-#define RMF_HAS_NOEXCEPT __has_feature(cxx_noexcept)
-#else
-#define RMF_HAS_NOEXCEPT 0
-#endif
-
-#if RMF_HAS_NOEXCEPT
+// Deprecated; just use 'noexcept' keyword instead
 #define RMF_NOEXCEPT noexcept
 #define RMF_CANEXCEPT noexcept(false)
+
 #define RMF_CXX11_DEFAULT_COPY_CONSTRUCTOR(Name) \
   Name(const Name &) = default;                  \
   Name &operator=(const Name &) = default
-#else
-// probably should be finer here
-#define RMF_NOEXCEPT throw()
-#define RMF_CANEXCEPT
-#define RMF_CXX11_DEFAULT_COPY_CONSTRUCTOR(Name)
-#endif
 
 #if defined(__clang__) || defined(__GNUC__)
 #define RMF_PRAGMA(x) _Pragma(RMF_STRINGIFY(x))
@@ -159,6 +122,18 @@
 #define RMF_GCC_PROTOTYPES
 #endif
 
+// Warn about missing override on virtual methods if gcc is new enough
+#if __GNUC__ > 5 || (__GNUC__ == 5 && __GNUC_MINOR__ >= 1)
+#ifdef RMF_SWIG_WRAPPER
+#define RMF_GCC_OVERRIDE
+#else
+#define RMF_GCC_OVERRIDE \
+  RMF_GCC_PRAGMA(diagnostic warning "-Wsuggest-override")
+#endif
+#else
+#define RMF_GCC_OVERRIDE
+#endif
+
 #define RMF_COMPILER_WARNINGS                                   \
   RMF_GCC_PRAGMA(diagnostic warning "-Wall")                    \
       RMF_GCC_PRAGMA(diagnostic warning "-Wextra")              \
@@ -166,8 +141,8 @@
       RMF_GCC_PRAGMA(diagnostic warning "-Wcast-align")         \
       RMF_GCC_PRAGMA(diagnostic warning "-Woverloaded-virtual") \
       RMF_GCC_PRAGMA(diagnostic ignored "-Wconversion")         \
-      RMF_GCC_PRAGMA(diagnostic warning                         \
-                     "-Wundef") RMF_GCC_PROTOTYPES RMF_GCC_CXX0X_COMPAT
+      RMF_GCC_PRAGMA(diagnostic warning "-Wundef")              \
+      RMF_GCC_PROTOTYPES RMF_GCC_CXX0X_COMPAT RMF_GCC_OVERRIDE
 
 #elif defined(_MSC_VER)
 #define RMF_COMPILER_WARNINGS                                           \
