@@ -2,6 +2,7 @@ from __future__ import print_function
 import unittest
 import RMF
 import shutil
+import utils
 
 
 class GenericTest(unittest.TestCase):
@@ -32,7 +33,7 @@ class GenericTest(unittest.TestCase):
         cf = RMF.ChainFactory(fh)
         n = fh.get_root_node().get_children()[0]
         RMF.show_hierarchy_with_values(n)
-        self.assert_(cf.get_is(n))
+        self.assertTrue(cf.get_is(n))
         chain = cf.get(n).get_chain_id()
         self.assertEqual(chain, "A")
 
