@@ -80,6 +80,30 @@ Restraints RMFRestraint::do_create_current_decomposition() const {
 RMFRestraint::RMFRestraint(Model *m, std::string name)
     : Restraint(m, name) {}
 
+class RMFRestraintSet;
+IMP_OBJECTS(RMFRestraintSet, RMFRestraintSets);
+/** A dummy restraint object to represent restraint sets loaded from
+    an RMF file.*/
+class RMFRestraintSet : public RestraintSet {
+  PointerMember<RestraintInfo> info_;
+
+ public:
+  RMFRestraintSet(const RestraintsTemp &rs, double weight,
+                  const std::string &name) : RestraintSet(rs, weight, name) {}
+
+#ifndef IMP_DOXYGEN
+  RestraintInfo *get_info() {
+    if (!info_) {
+      info_ = new RestraintInfo();
+    }
+    return info_;
+  }
+  RestraintInfo *get_dynamic_info() const override { return info_; }
+  RestraintInfo *get_static_info() const override { return info_; }
+#endif
+  IMP_OBJECT_METHODS(RMFRestraintSet);
+};
+
 class Subset : public ConstVector<WeakPointer<Particle>, Particle *> {
   typedef ConstVector<WeakPointer<Particle>, Particle *> P;
   static ParticlesTemp get_sorted(ParticlesTemp ps) {
@@ -102,6 +126,11 @@ class Subset : public ConstVector<WeakPointer<Particle>, Particle *> {
   }
 };
 
+inline std::size_t hash_value(const Subset &t) {
+  return t.__hash__();
+}
+
+
 IMP_VALUES(Subset, Subsets);
 
 template <class C>
@@ -159,6 +188,7 @@ class RestraintLoadLink : public SimpleLoadLink<Restraint> {
   typedef std::pair<std::string, ParticleIndexes> ParticleIndexesData;
   typedef SimpleLoadLink<Restraint> P;
   RMF::decorator::ScoreFactory sf_;
+  RMF::decorator::AliasFactory af_;
   RMF::decorator::RepresentationFactory rf_;
   RMF::decorator::GaussianParticleFactory gaussian_factory_;
   RMF::decorator::IntermediateParticleFactory ipf_;
@@ -234,12 +264,14 @@ class RestraintLoadLink : public SimpleLoadLink<Restraint> {
     }
     Pointer<Restraint> ret;
     if (!childr.empty()) {
-      ret = new RestraintSet(childr, 1.0, name.get_name());
+      IMP_NEW(RMFRestraintSet, r, (childr, 1.0, name.get_name()));
+      ret = r;
+      load_restraint_info(r->get_info(), name, static_pis, dynamic_pis);
     } else {
       IMP_NEW(RMFRestraint, r, (m, name.get_name()));
       ret = r;
       r->set_particles(inputs);
-      load_restraint_info(r, name, static_pis, dynamic_pis);
+      load_restraint_info(r->get_info(), name, static_pis, dynamic_pis);
     }
     if (name.get_has_value(weight_key_)) {
       ret->set_weight(name.get_value(weight_key_));
@@ -281,9 +313,15 @@ class RestraintLoadLink : public SimpleLoadLink<Restraint> {
       std::vector<ParticleIndexesData> &dynamic_pis) {
     ParticleIndexes pis;
     for(RMF::NodeConstHandle ch : parent.get_children()) {
-      Particle *p = get_association<Particle>(ch);
-      pis.push_back(p->get_index());
-      setup_particle(ch, m, p->get_index());
+      if (af_.get_is(ch)) {
+        Particle *p = get_association<Particle>(af_.get(ch).get_aliased());
+        pis.push_back(p->get_index());
+        // assume particle is already set up
+      } else {
+        Particle *p = get_association<Particle>(ch);
+        pis.push_back(p->get_index());
+        setup_particle(ch, m, p->get_index());
+      }
     }
     // todo: distinguish static and dynamic pis
     static_pis.push_back(ParticleIndexesData(parent.get_name(), pis));
@@ -340,29 +378,29 @@ class RestraintLoadLink : public SimpleLoadLink<Restraint> {
     }
   }
 
-  void load_restraint_info(RMFRestraint *r, RMF::NodeConstHandle nh,
+  void load_restraint_info(RestraintInfo *info, RMF::NodeConstHandle nh,
                            std::vector<ParticleIndexesData> &static_pis,
                            std::vector<ParticleIndexesData> &dynamic_pis) {
     RMF::FileConstHandle fh = nh.get_file();
     RMF_FOREACH(RMF::IntKey k, iks_) {
       if (!nh.get_value(k).get_is_null()) {
-        r->get_info()->add_int(fh.get_name(k), nh.get_value(k));
+        info->add_int(fh.get_name(k), nh.get_value(k));
       }
     }
     RMF_FOREACH(RMF::FloatKey k, fks_) {
       if (!nh.get_value(k).get_is_null()) {
-        r->get_info()->add_float(fh.get_name(k), nh.get_value(k));
+        info->add_float(fh.get_name(k), nh.get_value(k));
       }
     }
     RMF_FOREACH(RMF::StringKey k, sks_) {
       if (!nh.get_value(k).get_is_null()) {
-        r->get_info()->add_string(fh.get_name(k), nh.get_value(k));
+        info->add_string(fh.get_name(k), nh.get_value(k));
       }
     }
     RMF_FOREACH(RMF::StringKey k, filenameks_) {
       if (!nh.get_value(k).get_is_null()) {
-        r->get_info()->add_filename(fh.get_name(k),
-                                    RMF::internal::get_absolute_path(
+        info->add_filename(fh.get_name(k),
+                           RMF::internal::get_absolute_path(
                                             fh.get_path(), nh.get_value(k)));
       }
     }
@@ -371,7 +409,7 @@ class RestraintLoadLink : public SimpleLoadLink<Restraint> {
         // No automatic conversion from RMF::Floats to IMP::Floats
         RMF::Floats rvalue = nh.get_value(k);
         Floats value(rvalue.begin(), rvalue.end());
-        r->get_info()->add_floats(fh.get_name(k), value);
+        info->add_floats(fh.get_name(k), value);
       }
     }
     RMF_FOREACH(RMF::IntsKey k, isks_) {
@@ -379,7 +417,7 @@ class RestraintLoadLink : public SimpleLoadLink<Restraint> {
         // No automatic conversion from RMF::Ints to IMP::Ints
         RMF::Ints rvalue = nh.get_value(k);
         Ints value(rvalue.begin(), rvalue.end());
-        r->get_info()->add_ints(fh.get_name(k), value);
+        info->add_ints(fh.get_name(k), value);
       }
     }
     RMF_FOREACH(RMF::StringsKey k, ssks_) {
@@ -387,7 +425,7 @@ class RestraintLoadLink : public SimpleLoadLink<Restraint> {
         // No automatic conversion from RMF::Strings to IMP::Strings
         RMF::Strings rvalue = nh.get_value(k);
         Strings value(rvalue.begin(), rvalue.end());
-        r->get_info()->add_strings(fh.get_name(k), value);
+        info->add_strings(fh.get_name(k), value);
       }
     }
     RMF_FOREACH(RMF::StringsKey k, filenamesks_) {
@@ -398,17 +436,15 @@ class RestraintLoadLink : public SimpleLoadLink<Restraint> {
         for (const auto &it : rvalue) {
           value.push_back(RMF::internal::get_absolute_path(fh.get_path(), it));
         }
-        r->get_info()->add_filenames(fh.get_name(k), value);
+        info->add_filenames(fh.get_name(k), value);
       }
     }
 
     for (unsigned i = 0; i < static_pis.size(); ++i) {
-      r->get_info()->add_particle_indexes(static_pis[i].first,
-                                          static_pis[i].second);
+      info->add_particle_indexes(static_pis[i].first, static_pis[i].second);
     }
     for (unsigned i = 0; i < dynamic_pis.size(); ++i) {
-      r->get_info()->add_particle_indexes(dynamic_pis[i].first,
-                                          dynamic_pis[i].second);
+      info->add_particle_indexes(dynamic_pis[i].first, dynamic_pis[i].second);
     }
   }
 
@@ -416,6 +452,7 @@ class RestraintLoadLink : public SimpleLoadLink<Restraint> {
   RestraintLoadLink(RMF::FileConstHandle fh)
       : P("RestraintLoadLink%1%"),
         sf_(fh),
+        af_(fh),
         rf_(fh),
         gaussian_factory_(fh),
         ipf_(fh),
