@@ -2,7 +2,7 @@
  *  \file IMP/spb/spb_ISD_particles.h
  *  \brief SPB ISD particles
  *
- *  Copyright 2007-2018 IMP Inventors. All rights reserved.
+ *  Copyright 2007-2022 IMP Inventors. All rights reserved.
  *
  */
 
@@ -14,7 +14,7 @@
 #include <IMP/spb/spb_main.h>
 #include <map>
 #include <string>
-#include "spb_config.h"
+#include <IMP/spb/spb_config.h>
 
 IMPSPB_BEGIN_NAMESPACE
 
