@@ -10,23 +10,23 @@ import glob
 import pickle
 
 sys.path.append(os.path.join(os.path.dirname(sys.argv[0]), '..', 'build'))
-import tools
+import tools  # noqa: E402
 
 
 def setup_excludes(cov):
     # Try to exclude SWIG and IMP boilerplate from coverage checks
-    cov.exclude("def swig_import_helper\(")
+    cov.exclude(r"def swig_import_helper\(")
     cov.exclude("def _swig_")
-    cov.exclude("class (_ostream|_DirectorObjects|"
-                "IMP_\w+_SwigPyIterator)\(")
-    cov.exclude("^\s+import _IMP_")
+    cov.exclude(r"class (_ostream|_DirectorObjects|"
+                r"IMP_\w+_SwigPyIterator)\(")
+    cov.exclude(r"^\s+import _IMP_")
     cov.exclude("^except (Name|Attribute)Error:")
-    cov.exclude("^\s+weakref_proxy =")
-    cov.exclude("^except:\s*$")
+    cov.exclude(r"^\s+weakref_proxy =")
+    cov.exclude(r"^except:\s*$")
     cov.exclude("^def [sg]et_check_level")
-    cov.exclude("^\s+__setattr__ = lambda self, name, value: _swig_setattr")
-    cov.exclude("^\s+__getattr__ = lambda self, name: _swig_getattr")
-    cov.exclude("^\s+__swig_[sg]etmethods__\[\".*\"\] = lambda ")
+    cov.exclude(r"^\s+__setattr__ = lambda self, name, value: _swig_setattr")
+    cov.exclude(r"^\s+__getattr__ = lambda self, name: _swig_getattr")
+    cov.exclude(r"^\s+__swig_[sg]etmethods__\[\".*\"\] = lambda ")
 
 
 def report_python_component(cov, morfs, name, typ, reldir, outdir):
@@ -182,9 +182,9 @@ Generate HTML coverage reports for IMP C++/Python code in the given directory.
                            "coverage for all modules is reported.")
     parser.add_option("--dependencies", metavar='STR', default=None,
                       help="Report only for the given colon-separated list of "
-                           "IMP dependencies, e.g. 'RMF'. By default, coverage "
-                           "for all supported dependencies (currently only "
-                           "RMF) is reported.")
+                           "IMP dependencies, e.g. 'RMF'. By default, "
+                           "coverage for all supported dependencies "
+                           "(currently only RMF) is reported.")
     parser.add_option("--exclude", metavar='PCK', default=None,
                       help="Don't report coverage for any of the components "
                            "listed in the given summary file (as generated by "
@@ -209,5 +209,6 @@ def main():
     if opts.report in ('both', 'cpp'):
         report_cpp(opts, outdir)
 
+
 if __name__ == '__main__':
     main()
