@@ -7,7 +7,8 @@ import re
 
 
 def fix(filename):
-    contents = open(filename, "r").read()
+    with open(filename, "r") as fh:
+        contents = fh.read()
     contents = re.sub(
         "\\\\file .*\\.h",
         "\\\\file " + filename[len("build/include/"):],
@@ -22,6 +23,7 @@ def fix(filename):
     f.truncate()
     f.write(contents)
 
+
 if __name__ == '__main__':
     for f in sys.argv[1:]:
         fix(f)
