@@ -118,61 +118,36 @@ PYVERS="36 37 38 39 310 311"
 if [ "${BITS}" = "32" ]; then
   MAKENSIS="makensis"
   DLLSRC=/usr/lib/w32comp/windows/system
-
-  # Add redist MSVC runtime DLLs
-  cp ${DLLSRC}/msvcp140.dll ${DLLSRC}/concrt140.dll ${DLLSRC}/vcruntime140.dll \
-     ${ROOT}/bin || exit 1
-
-  # Add other DLL dependencies
-  cp ${DLLSRC}/hdf5.dll ${DLLSRC}/libgsl.dll ${DLLSRC}/libgslcblas.dll \
-     ${DLLSRC}/boost_filesystem-vc140-mt-x${BITS}-1_72.dll \
-     ${DLLSRC}/boost_program_options-vc140-mt-x${BITS}-1_72.dll \
-     ${DLLSRC}/boost_system-vc140-mt-x${BITS}-1_72.dll \
-     ${DLLSRC}/boost_date_time-vc140-mt-x${BITS}-1_72.dll \
-     ${DLLSRC}/boost_graph-vc140-mt-x${BITS}-1_72.dll \
-     ${DLLSRC}/boost_regex-vc140-mt-x${BITS}-1_72.dll \
-     ${DLLSRC}/boost_thread-vc140-mt-x${BITS}-1_72.dll \
-     ${DLLSRC}/boost_random-vc140-mt-x${BITS}-1_72.dll \
-     ${DLLSRC}/boost_iostreams-vc140-mt-x${BITS}-1_72.dll \
-     ${DLLSRC}/boost_zlib-vc140-mt-x${BITS}-1_72.dll \
-     ${DLLSRC}/boost_serialization-vc140-mt-x${BITS}-1_72.dll \
-     ${DLLSRC}/libgmp-10.dll \
-     ${DLLSRC}/libmpfr-4.dll \
-     ${DLLSRC}/libfftw3-3.dll \
-     ${DLLSRC}/libTAU1.dll \
-     ${DLLSRC}/zlib1.dll \
-     ${DLLSRC}/opencv_core455.dll ${DLLSRC}/opencv_highgui455.dll \
-     ${DLLSRC}/opencv_imgcodecs455.dll ${DLLSRC}/opencv_videoio455.dll \
-     ${DLLSRC}/opencv_imgproc455.dll ${ROOT}/bin || exit 1
 else
   MAKENSIS="makensis -DIMP_64BIT"
   DLLSRC=/usr/lib/w64comp/windows/system32
-  # Add redist MSVC runtime DLLs
-  cp ${DLLSRC}/msvc*110.dll ${ROOT}/bin || exit 1
-  # Add other DLL dependencies
-  cp ${DLLSRC}/hdf5.dll ${DLLSRC}/libgsl.dll ${DLLSRC}/libgslcblas.dll \
-     ${DLLSRC}/boost_filesystem-vc110-mt-1_55.dll \
-     ${DLLSRC}/boost_program_options-vc110-mt-1_55.dll \
-     ${DLLSRC}/boost_system-vc110-mt-1_55.dll \
-     ${DLLSRC}/boost_date_time-vc110-mt-1_55.dll \
-     ${DLLSRC}/boost_graph-vc110-mt-1_55.dll \
-     ${DLLSRC}/boost_regex-vc110-mt-1_55.dll \
-     ${DLLSRC}/boost_thread-vc110-mt-1_55.dll \
-     ${DLLSRC}/boost_random-vc110-mt-1_55.dll \
-     ${DLLSRC}/boost_iostreams-vc110-mt-1_55.dll \
-     ${DLLSRC}/boost_zlib-vc110-mt-1_55.dll \
-     ${DLLSRC}/boost_chrono-vc110-mt-1_55.dll \
-     ${DLLSRC}/boost_serialization-vc110-mt-1_55.dll \
-     ${DLLSRC}/CGAL-vc110-mt-4.4.dll \
-     ${DLLSRC}/libgmp-10.dll \
-     ${DLLSRC}/libmpfr-4.dll \
-     ${DLLSRC}/libfftw3-3.dll \
-     ${DLLSRC}/libTAU1.dll \
-     ${DLLSRC}/zlib1.dll \
-     ${DLLSRC}/opencv_core248.dll ${DLLSRC}/opencv_highgui248.dll \
-     ${DLLSRC}/opencv_imgproc248.dll ${ROOT}/bin || exit 1
 fi
 
+# Add redist MSVC runtime DLLs
+cp ${DLLSRC}/msvcp140.dll ${DLLSRC}/concrt140.dll ${DLLSRC}/vcruntime140.dll \
+   ${ROOT}/bin || exit 1
+
+# Add other DLL dependencies
+cp ${DLLSRC}/hdf5.dll ${DLLSRC}/libgsl.dll ${DLLSRC}/libgslcblas.dll \
+   ${DLLSRC}/boost_filesystem-vc140-mt-x${BITS}-1_72.dll \
+   ${DLLSRC}/boost_program_options-vc140-mt-x${BITS}-1_72.dll \
+   ${DLLSRC}/boost_system-vc140-mt-x${BITS}-1_72.dll \
+   ${DLLSRC}/boost_date_time-vc140-mt-x${BITS}-1_72.dll \
+   ${DLLSRC}/boost_graph-vc140-mt-x${BITS}-1_72.dll \
+   ${DLLSRC}/boost_regex-vc140-mt-x${BITS}-1_72.dll \
+   ${DLLSRC}/boost_thread-vc140-mt-x${BITS}-1_72.dll \
+   ${DLLSRC}/boost_random-vc140-mt-x${BITS}-1_72.dll \
+   ${DLLSRC}/boost_iostreams-vc140-mt-x${BITS}-1_72.dll \
+   ${DLLSRC}/boost_zlib-vc140-mt-x${BITS}-1_72.dll \
+   ${DLLSRC}/libgmp-10.dll \
+   ${DLLSRC}/libmpfr-4.dll \
+   ${DLLSRC}/libfftw3-3.dll \
+   ${DLLSRC}/libTAU1.dll \
+   ${DLLSRC}/zlib1.dll \
+   ${DLLSRC}/opencv_core455.dll ${DLLSRC}/opencv_highgui455.dll \
+   ${DLLSRC}/opencv_imgcodecs455.dll ${DLLSRC}/opencv_videoio455.dll \
+   ${DLLSRC}/opencv_imgproc455.dll ${ROOT}/bin || exit 1
+
 # Check all installed binaries for DLL dependencies, to make sure we
 # didn't miss any
 dumpbin /DEPENDENTS ${ROOT}/bin/*.exe ${ROOT}/bin/*.dll ${ROOT}/python/*/*.pyd \
